@@ -1,5 +1,5 @@
 # Schedule::Load::Reporter.pm -- distributed lock handler
-# $Id: Reporter.pm,v 1.49 2004/03/04 16:33:58 wsnyder Exp $
+# $Id: Reporter.pm,v 1.52 2004/10/26 17:12:16 ws150726 Exp $
 ######################################################################
 #
 # Copyright 2000-2004 by Wilson Snyder.  This program is free software;
@@ -47,7 +47,7 @@ use Carp;
 # Other configurable settings.
 $Debug = $Schedule::Load::Debug;
 
-$VERSION = '3.010';
+$VERSION = '3.020';
 
 $RSCHLIB = '/usr/local/lib';	# Edited by Makefile
 
@@ -593,7 +593,7 @@ Schedule::Load::Reporter - Distributed load reporting daemon
 
 =head1 DESCRIPTION
 
-C<Schedule::Load::Reporter> on startup connects to the requested server
+L<Schedule::Load::Reporter> on startup connects to the requested server
 host and port.  The server connected to can then poll this host for
 information about system configuration and current loading conditions.
 
@@ -640,16 +640,20 @@ is lost.)   The path must be **ABSOLUTE** as the daemons do a chdir.
 
 =back
 
-=head1 SEE ALSO
-
-C<Schedule::Load>, C<slreportd>
-
 =head1 DISTRIBUTION
 
-This package is distributed via CPAN.
+The latest version is available from CPAN and from L<http://www.veripool.com/>.
+
+Copyright 1998-2004 by Wilson Snyder.  This package is free software; you
+can redistribute it and/or modify it under the terms of either the GNU
+Lesser General Public License or the Perl Artistic License.
 
 =head1 AUTHORS
 
 Wilson Snyder <wsnyder@wsnyder.org>
 
+=head1 SEE ALSO
+
+L<Schedule::Load>, L<slreportd>
+
 =cut
